Module reader

Module reader 

Reader is used for reading items from datasource (e.g. stdin or command output)

After reading in a line, reader will save an item into the pool(items)

Structs

Reader
Reader for streaming items from commands or other sources
ReaderControl
Handle for controlling a running reader

Traits

CommandCollector
Trait for collecting items from command output